@@ -24,6 +24,9 @@ Download
     __init__(commcell_object)        --  initialize commcell_object of Install class
     associated with the commcell
 
+    repair_software                -- triggers Repair of the software on a specified
+                                        client/client group
+
     push_servicepack_and_hotfix()    --  installs the latest service pack in the client machine
 
     install_software                 --  Installs the features selected on the machines selected
@@ -52,6 +55,141 @@ class Install(object):
         self._services = commcell_object._services
         self._cvpysdk_object = commcell_object._cvpysdk_object
 
+    def repair_software(self,
+                        client=None,
+                        client_group=None,
+                        username=None,
+                        password=None,
+                        reboot_client=False):
+        """triggers Repair of the software for a specified client machine
+
+                Args:
+                    client (str)               -- Client machine to re-install service pack on
+
+                    client_group (str)         -- Client group to re-install service pack on
+                                                            (eg : 'Media Agent')
+
+                    username    (str)               -- username of the machine to re-install features on
+
+                        default : None
+
+                    password    (str)               -- base64 encoded password
+
+                        default : None
+
+                    reboot_client (bool)            -- boolean to specify whether to reboot the client
+                    or not
+
+                        default: False
+
+                Returns:
+                    object - instance of the Job class for this download job
+
+                Raises:
+                        SDKException:
+                        if re-install job failed
+
+                        if response is empty
+
+                        if response is not success
+
+        **NOTE:** repair_software can be used for client/ client_group not both; When both inputs are given only the
+                  client computer will be repaired
+
+        **NOTE:** If machine requires reboot and reboot is not selected, machine won't be updated
+
+        **NOTE:** If machine requires login credentials and if not provided - client reinstallation might fail.
+
+        """
+        if (client is None) and (client_group is None):
+            raise SDKException('Install', '100')
+
+        if client:
+            client_group = ""
+            if not client in self.commcell_object.clients.all_clients:
+                raise SDKException('Install', '101')
+
+        elif client_group:
+            client = ""
+            if not client_group in self.commcell_object.client_groups.all_clientgroups:
+                raise SDKException('Install', '102')
+
+        request_json = {
+            "taskInfo": {
+                "task": {
+                    "taskType": 1,
+                    "initiatedFrom": 2,
+                    "policyType": 0,
+                    "taskFlags": {
+                        "disabled": False
+                    }
+                },
+                "subTasks": [
+                    {
+                        "subTaskOperation": 1,
+                        "subTask": {
+                            "subTaskType": 1,
+                            "operationType": 4020
+                        },
+                        "options": {
+                            "adminOpts": {
+                                "clientInstallOption": {
+                                    "installerOption": {
+                                        "clientComposition": [
+                                            {
+                                                "packageDeliveryOption": 0
+                                            }
+                                        ]
+                                    }
+                                },
+                                "updateOption": {
+                                    "installUpdateOptions": 0,
+                                    "restartExplorerPlugin": True,
+                                    "rebootClient": reboot_client,
+                                    "clientAndClientGroups": [
+                                        {
+                                            "clientGroupName" : client_group,
+                                            "clientName": client
+                                        }
+                                    ],
+                                    "installUpdatesJobType": {
+                                        "installType": 4,
+                                        "upgradeClients": False,
+                                        "undoUpdates": False,
+                                        "installUpdates": False
+                                    }
+                                }
+                            }
+                        }
+                    }
+                ]
+            }
+        }
+
+        if username:
+            request_json["taskInfo"]["subTasks"][0]["options"]["adminOpts"]["clientInstallOption"]["clientAuthForJob"] \
+                = {
+                    "password": password,
+                    "userName": username
+                }
+
+        flag, response = self._cvpysdk_object.make_request(
+            'POST', self._services['CREATE_TASK'], request_json
+        )
+
+        if flag:
+            if response.json():
+                if "jobIds" in response.json():
+                    return Job(self.commcell_object, response.json()['jobIds'][0])
+
+                else:
+                    raise SDKException('Install', '107')
+
+            else:
+                raise SDKException('Response', '102')
+        else:
+            raise SDKException('Response', '101')
+
     def push_servicepack_and_hotfix(
             self,
             client_computers=None,
@@ -202,7 +340,8 @@ class Install(object):
             windows_features=None,
             unix_features=None,
             username=None,
-            password=None):
+            password=None,
+            install_path=None):
         """
         Installs the features selected on the given machines
         Args:
@@ -228,6 +367,10 @@ class Install(object):
 
                 default : None
 
+            install_path (str)              -- Install to a specified path on the client
+
+                 default : None
+
         Returns:
                 object - instance of the Job class for this install_software job
 
@@ -254,7 +397,8 @@ class Install(object):
                                 windows_features=[WindowsDownloadFeatures.FILE_SYSTEM.value],
                                 unix_features=None,
                                 username='username',
-                                password='password')
+                                password='password',
+                                install_path='C:\\Temp)
 
                     **NOTE:** Either Unix or Windows clients_computers should be chosen and
                     not both
@@ -359,7 +503,8 @@ class Install(object):
                                                 "clientInfo": {
                                                     "client": {
                                                         "evmgrcPort": 0,
-                                                        "cvdPort": 0
+                                                        "cvdPort": 0,
+                                                        "installDirectory": install_path if install_path else ""
                                                     }
                                                 }
                                             }
@@ -380,6 +525,7 @@ class Install(object):
                 ]
             }
         }
+
         flag, response = self._cvpysdk_object.make_request(
             'POST', self._services['CREATE_TASK'], request_json
         )
